@@ -1,10 +1,14 @@
 __all__ = [
     "Power",
     "device_info",
+    "device_info_get_alarm_reset",
     "device_info_get_environment_temperature",
+    "device_info_get_perform_cochlea_loading",
     "device_info_get_power",
     "device_info_get_target_temperature",
     "discover_devices",
+    "discover_devices_helper",
+    "get_perform_cochlea_loading",
     "get_environment_temperature",
     "get_power",
     "get_target_temperature",
@@ -18,11 +22,15 @@ __all__ = [
 from edilkamin.api import (
     Power,
     device_info,
+    device_info_get_alarm_reset,
     device_info_get_environment_temperature,
+    device_info_get_perform_cochlea_loading,
     device_info_get_power,
     device_info_get_target_temperature,
     discover_devices,
+    discover_devices_helper,
     get_environment_temperature,
+    get_perform_cochlea_loading,
     get_power,
     get_target_temperature,
     mqtt_command,
